#!/bin/sh

[ -n "$EH_PREFIX" ] && export PREFIX="$EH_PREFIX"
if [ -z "$PREFIX" ]; then
	echo "ERROR: set \$PREFIX before sourcing this script!"
	exit 1
fi

[ "$FINK_X11" = "true"  ] && export FINK_X11=1
[ "$FINK_X11" = "yes"   ] && export FINK_X11=1
[ "$FINK_X11" = "false" ] && export FINK_X11=0
[ "$FINK_X11" = "no"    ] && export FINK_X11=0
[ -z "$FINK_X11"        ] && export FINK_X11=0

export LDFLAGS=""

# set some basic OS stuff
SW_VERSION=`sw_vers -productVersion | cut -d. -f1-2`
case $SW_VERSION in
	10.[01])
		echo "unsupported OS version: $SW_VERSION"
		exit 1
		;;
	10.2)
		export MACOSX_DEPLOYMENT_TARGET=10.2
		FREETYPE_CONFIG=$PREFIX/bin/freetype-config
		;;
	10.3)
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config
		;;
	10.4)
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config

		GCCCMD="gcc"
		[ -n "$CC" ] && GCCCMD="$CC"

		if [ `$GCCCMD --version 2>&1 | grep -c ' 4.0.0 '` -gt 0 ]; then
			cat <<END
=== ERROR === ERROR === ERROR === ERROR === ERROR === ERROR ===

You are using GCC 4.0.0, which is known to compile KDE, but
produce bad code.  Please update to XCode 2.2 or higher.

=== ERROR === ERROR === ERROR === ERROR === ERROR === ERROR ===
END
			exit 1
		fi
		;;
	10.5)
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		export LDFLAGS="-Wl,-dylib_file,/System/Library/Frameworks/OpenGL.framework/Versions/A/Libraries/libGL.dylib:/System/Library/Frameworks/OpenGL.framework/Versions/A/Libraries/libGL.dylib -Wl,-dead_strip_dylibs"
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config
		;;
	*)
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		export LDFLAGS="-Wl,-dead_strip_dylibs"
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config
		;;
esac

if [ -n "$USE_UNSERMAKE" ] && [ "$USE_UNSERMAKE" -gt 0 ]; then
	UNSERMAKEFLAGS=`perl -e '$ENV{MAKEFLAGS} =~ s/^.*?-j(\d+).*?$/-j1 --compile-jobs=$1/; print $ENV{MAKEFLAGS}'`
	UNSERMAKEFLAGS="$UNSERMAKEFLAGS -p"
	MAKEFLAGS=""
fi


SEARCHDIRS="$PREFIX/lib/system-openssl $PREFIX/lib/freetype219 $PREFIX/lib/flex $PREFIX/lib/doxygen1.3"
[ "$FINK_X11" -eq 1 ] && SEARCHDIRS="$SEARCHDIRS $PREFIX/X11"

for dir in $SEARCHDIRS; do
	if [ -d "$dir" ]; then
		for incdir in "$dir/include/freetype2" "$dir/include"; do
			if [ -d "$incdir" ]; then
				export CPPFLAGS="$CPPFLAGS -I$incdir"
			fi
		done
		[ -d "$dir/lib" ]           && export LDFLAGS="-L$dir/lib $LDFLAGS"
		[ -d "$dir/bin" ]           && export PATH="$dir/bin:$PATH"
		[ -d "$dir/lib/pkgconfig" ] && export PKG_CONFIG_PATH="$dir/lib/pkgconfig:$PKG_CONFIG_PATH"
	fi
done

# -fast, minus the unsafe bits
if [ -d "libltdl" ]; then
	export ACLOCALFLAGS="$ACLOCALFLAGS -I libltdl"
fi
export CFLAGS="-Os -fPIC"
export CXXFLAGS="$CFLAGS"
export CPPFLAGS="$CPPFLAGS -fno-common -no-cpp-precomp -DMACOSX -DARTS_NO_ALARM -I$PREFIX/include"
export FREETYPE_CONFIG
export LIBS="$LIBS -L$PREFIX/lib"
export SED="sed"
export CONFIGURE_PARAMS="--includedir=$PREFIX/include --libdir=$PREFIX/lib --prefix=$PREFIX --with-extra-libs=$PREFIX/lib --with-extra-includes=$PREFIX/include --enable-mt --with-pic --enable-rpath --enable-shared=yes --enable-static=no --mandir=$PREFIX/share/man --with-xinerama --with-pam --disable-final --with-ssl-dir=/usr --with-ssl --disable-dependency-tracking --enable-gcc-hidden-visibility"

if [ "$FINK_X11" -eq 1 ]; then
	CPPFLAGS="$CPPFLAGS -I$PREFIX/X11/include"
	LIBS="$LIBS -L$PREFIX/X11/lib"
	export ac_cv_have_x="have_x=yes ac_x_includes=$PREFIX/X11/include ac_x_libraries=$PREFIX/X11/lib"
	export kde_cv_have_x="have_x=yes kde_x_includes=$PREFIX/X11/include kde_x_libraries=$PREFIX/X11/lib"
	export x_includes="$PREFIX/X11/include" x_libraries="$PREFIX/X11/lib"
	export XMKMF="$PREFIX/X11/bin/xorg-xmkmf" IMAKE="$PREFIX/X11/bin/xorg-imake"
else
	CPPFLAGS="$CPPFLAGS -I/usr/X11R6/include"
	LIBS="$LIBS -L/usr/X11R6/lib"
fi

# miscellaneous stuff that packages use
export lt_cv_sys_max_cmd_len=65536
export HOME=/tmp
export QTDOCDIR="$PREFIX/share/doc/qt3/html"
[ -x "$PREFIX/lib/flex/bin/flex" ] && export LEX="$PREFIX/lib/flex/bin/flex"

if [ -e "$PREFIX/lib/qt3/include" ]; then
	CONFIGURE_PARAMS="$CONFIGURE_PARAMS --with-qt-dir=$PREFIX/lib/qt3"
else
	CONFIGURE_PARAMS="$CONFIGURE_PARAMS --with-qt-dir=$PREFIX --with-qt-includes=$PREFIX/include/qt"
fi

PATH=`echo $PATH | perl -p -e 'for my $entry (split(/:/, $_)) { next if ($entry =~ m,^/usr/local,); push(@path, $entry) }; $_ = join(":", @path)'`

if [ -x "$PREFIX/lib/xmkmf/bin" ]; then
	export PATH="$PREFIX/lib/xmkmf/bin:$PATH"
	export IMAKEINCLUDE="-I$PREFIX/lib/X11/config"
fi

if [ "$FINK_X11" -eq 1 ]; then
	export PATH="$PATH:$PREFIX/X11/bin"

	if [ `grep -r /usr/X11R6 admin 2>/dev/null | wc -l` -gt 0 ]; then
		echo "*** replacing /usr/X11R6 with $PREFIX/X11 in the admin/ directory ***"
		find admin -type f | xargs perl -pi -e "s,/usr/X11R6,$PREFIX/X11,g"
	fi
else
	export PATH="$PATH:/usr/X11R6/bin"
fi

if [ -x "/usr/bin/gcc-4.2" ]; then
	if [ -x "$PREFIX/bin/ccache" ]; then
		mkdir -p gcc-root
		[ ! -e gcc-root/gcc-4.2 ] && ln -s $PREFIX/bin/ccache gcc-root/gcc-4.2
		[ ! -e gcc-root/g++-4.2 ] && ln -s $PREFIX/bin/ccache gcc-root/g++-4.2
		export PATH=`pwd`/gcc-root:"$PATH"
		export CC="gcc-4.2"
		export CXX="g++-4.2"
	else
		export CC="/usr/bin/gcc-4.2"
		export CXX="/usr/bin/g++-4.2"
	fi
else
	export CC="gcc"
	export CXX="g++"
fi

export ALL_LIBRARIES="$LDFLAGS $LIBS"

cat <<END
the following environment is being used:

  ACLOCALFLAGS:             $ACLOCALFLAGS
  CFLAGS:                   $CFLAGS
  CPPFLAGS:                 $CPPFLAGS
  CXXFLAGS:                 $CXXFLAGS
  CC:                       $CC
  CXX:                      $CXX
  FREETYPE_CONFIG:          $FREETYPE_CONFIG
  LDFLAGS:                  $LDFLAGS
  LIBS:                     $LIBS
  MACOSX_DEPLOYMENT_TARGET: $MACOSX_DEPLOYMENT_TARGET
  PATH:                     $PATH
  PKG_CONFIG_PATH:          $PKG_CONFIG_PATH
  CONFIGURE_PARAMS:         $CONFIGURE_PARAMS
  UNSERMAKEFLAGS:           $UNSERMAKEFLAGS
  MAKEFLAGS:                $MAKEFLAGS

END
